package org.dromara.ems.base.mapper;

import org.dromara.ems.base.domain.EmsBaseEnergyPrice;

import java.util.List;

/**
 * 能源月份单价Mapper接口
 * 
 * @author Yinq
 * @date 2024-05-08
 */
public interface EmsBaseEnergyPriceMapper 
{
    /**
     * 查询能源月份单价
     * 
     * @param objId 能源月份单价主键
     * @return 能源月份单价
     */
    public EmsBaseEnergyPrice selectEmsBaseEnergyPriceByObjId(Long objId);

    /**
     * 查询能源月份单价列表
     * 
     * @param emsBaseEnergyPrice 能源月份单价
     * @return 能源月份单价集合
     */
    public List<EmsBaseEnergyPrice> selectEmsBaseEnergyPriceList(EmsBaseEnergyPrice emsBaseEnergyPrice);

    /**
     * 新增能源月份单价
     * 
     * @param emsBaseEnergyPrice 能源月份单价
     * @return 结果
     */
    public int insertEmsBaseEnergyPrice(EmsBaseEnergyPrice emsBaseEnergyPrice);

    /**
     * 修改能源月份单价
     * 
     * @param emsBaseEnergyPrice 能源月份单价
     * @return 结果
     */
    public int updateEmsBaseEnergyPrice(EmsBaseEnergyPrice emsBaseEnergyPrice);

    /**
     * 删除能源月份单价
     * 
     * @param objId 能源月份单价主键
     * @return 结果
     */
    public int deleteEmsBaseEnergyPriceByObjId(Long objId);

    /**
     * 批量删除能源月份单价
     * 
     * @param objIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteEmsBaseEnergyPriceByObjIds(Long[] objIds);
}
